# `certificate-check`

**Usage**:

```console
$ certificate-check [OPTIONS] FILENAME
```

**Arguments**:

* `FILENAME`: The certificate file to use (must finish with .cer)  [required]

**Options**:

* `--forcedownload / --no-forcedownload`: Redownloads the CRL file if it already exists  [default: no-forcedownload]
* `--install-completion`: Install completion for the current shell.
* `--show-completion`: Show completion for the current shell, to copy it or customize the installation.
* `--help`: Show this message and exit.
